<?php

declare(strict_types=1);

namespace Dedi\SyliusMailAdminPlugin\Handler;

use Dedi\SyliusMailAdminPlugin\Event\MailPreRenderEvent;
use Sylius\Component\Core\Model\OrderInterface;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\Routing\RouterInterface;
use Twig\Environment;

class OrderConfirmationHandler implements MailVariablesHandlerInterface
{
    private readonly RouterInterface $router;

    private readonly Environment $environment;

    public function __construct(
        RouterInterface $router,
        Environment $environment
    ) {
        $this->router = $router;
        $this->environment = $environment;
    }

    public function handle(MailPreRenderEvent $event): MailPreRenderEvent
    {
        $data = $event->getData();

        /** @var OrderInterface $order */
        $order = $data['order'];

        $data['orderUrl'] = $this->router->generate('sylius_shop_account_order_show', [
            'number' => $order->getNumber(),
        ], UrlGeneratorInterface::ABSOLUTE_URL);
        $data['order_items_table'] = $this->environment->render('@DediSyliusMailAdminPlugin/Admin/Mail/Order/_items.html.twig', [
            'order' => $order,
        ]);
        $event->setData($data);

        return $event;
    }
}
